.. currentmodule:: burin

==========
Exceptions
==========

Burin uses a few custom exceptions.  Where any of these may be raised is
documented in class, method, or function descriptions.

.. autoexception:: ConfigError

.. autoexception:: FactoryError

.. autoexception:: FormatError
